@@ -14,6 +14,10 @@ def test(
     skip=False,
     stage=None,
 ):
+    version_info = tuple(int(n) for n in cocotb.__version__.split("."))
+    if version_info >= (1, 7, 0) and stage is None:
+        stage = 0
+
     def decorator(cls):
 
         # create cocotb.test object to be picked up RegressionManager
