@@ -395,7 +395,7 @@ class uvm_root(uvm_component, metaclass=utility_classes.UVM_ROOT_Singleton):
 # is using it, and in fact it is recommended that people
 # stick to the basic phases.  So this implementation loops
 # through the hierarchy and runs the phases.
-    async def run_test(self, test_name, keep_singletons=False, keep_set={}):
+    async def run_test(self, test_name, keep_singletons=False, keep_set=set()):
         """
         :param test_name: The uvm test name or test class
         :param keep_singletons: If True do not clear singletons (default False)
@@ -562,11 +562,11 @@ class ConfigDB(metaclass=utility_classes.Singleton):
 
         except TypeError:
             raise error_classes.UVMConfigItemNotFound(
-                f'"{inst_name}" is not a in ConfigDB().')
+                f'"{inst_name}" is not in ConfigDB().')
         finally:
             if len(key_matches) == 0:
                 raise error_classes.UVMConfigItemNotFound(
-                    f'"{inst_name}" is not a in ConfigDB().')
+                    f'"{inst_name}" is not in ConfigDB().')
         # Here we sort the list of paths by which paths are "in" other
         # paths. That is A comes before '*'  A.B comes before A.*, etc.
         # We use an insertion sort. A path is inserted in front of the
